@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -22,7 +22,7 @@ use Composer\Package\Version\VersionParser;
  */
 class UpdateOperation extends SolverOperation implements OperationInterface
 {
-    const TYPE = 'update';
+    protected const TYPE = 'update';
 
     /**
      * @var PackageInterface
@@ -49,7 +49,7 @@ class UpdateOperation extends SolverOperation implements OperationInterface
      *
      * @return PackageInterface
      */
-    public function getInitialPackage()
+    public function getInitialPackage(): PackageInterface
     {
         return $this->initialPackage;
     }
@@ -59,7 +59,7 @@ class UpdateOperation extends SolverOperation implements OperationInterface
      *
      * @return PackageInterface
      */
-    public function getTargetPackage()
+    public function getTargetPackage(): PackageInterface
     {
         return $this->targetPackage;
     }
@@ -67,7 +67,7 @@ class UpdateOperation extends SolverOperation implements OperationInterface
     /**
      * @inheritDoc
      */
-    public function show($lock)
+    public function show($lock): string
     {
         return self::format($this->initialPackage, $this->targetPackage, $lock);
     }
@@ -76,7 +76,7 @@ class UpdateOperation extends SolverOperation implements OperationInterface
      * @param bool $lock
      * @return string
      */
-    public static function format(PackageInterface $initialPackage, PackageInterface $targetPackage, $lock = false)
+    public static function format(PackageInterface $initialPackage, PackageInterface $targetPackage, bool $lock = false): string
     {
         $fromVersion = $initialPackage->getFullPrettyVersion();
         $toVersion = $targetPackage->getFullPrettyVersion();
