@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -61,15 +61,13 @@ class RootPackageLoader extends ArrayLoader
     /**
      * @inheritDoc
      *
-     * @template PackageClass of RootPackage
-     *
      * @param string|null $cwd
      *
      * @return RootPackage|RootAliasPackage
      *
-     * @phpstan-param class-string<PackageClass> $class
+     * @phpstan-param class-string<RootPackage> $class
      */
-    public function load(array $config, $class = 'Composer\Package\RootPackage', $cwd = null)
+    public function load(array $config, string $class = 'Composer\Package\RootPackage', ?string $cwd = null): BasePackage
     {
         if ($class !== 'Composer\Package\RootPackage') {
             trigger_error('The $class arg is deprecated, please reach out to Composer maintainers ASAP if you still need this.', E_USER_DEPRECATED);
@@ -88,7 +86,7 @@ class RootPackageLoader extends ArrayLoader
             if (Platform::getEnv('COMPOSER_ROOT_VERSION')) {
                 $config['version'] = Platform::getEnv('COMPOSER_ROOT_VERSION');
             } else {
-                $versionData = $this->versionGuesser->guessVersion($config, $cwd ?: getcwd());
+                $versionData = $this->versionGuesser->guessVersion($config, $cwd ?? Platform::getCwd(true));
                 if ($versionData) {
                     $config['version'] = $versionData['pretty_version'];
                     $config['version_normalized'] = $versionData['version'];
@@ -194,7 +192,7 @@ class RootPackageLoader extends ArrayLoader
      *
      * @return list<array{package: string, version: string, alias: string, alias_normalized: string}>
      */
-    private function extractAliases(array $requires, array $aliases)
+    private function extractAliases(array $requires, array $aliases): array
     {
         foreach ($requires as $reqName => $reqVersion) {
             if (Preg::isMatch('{^([^,\s#]+)(?:#[^ ]+)? +as +([^,\s]+)$}', $reqVersion, $match)) {
@@ -224,7 +222,7 @@ class RootPackageLoader extends ArrayLoader
      * @phpstan-param array<string, BasePackage::STABILITY_*> $stabilityFlags
      * @phpstan-return array<string, BasePackage::STABILITY_*>
      */
-    public static function extractStabilityFlags(array $requires, $minimumStability, array $stabilityFlags)
+    public static function extractStabilityFlags(array $requires, string $minimumStability, array $stabilityFlags): array
     {
         $stabilities = BasePackage::$stabilities;
         /** @var int $minimumStability */
@@ -242,7 +240,7 @@ class RootPackageLoader extends ArrayLoader
             }
 
             // parse explicit stability flags to the most unstable
-            $match = false;
+            $matched = false;
             foreach ($constraints as $constraint) {
                 if (Preg::isMatch('{^[^@]*?@('.implode('|', array_keys($stabilities)).')$}i', $constraint, $match)) {
                     $name = strtolower($reqName);
@@ -252,11 +250,11 @@ class RootPackageLoader extends ArrayLoader
                         continue;
                     }
                     $stabilityFlags[$name] = $stability;
-                    $match = true;
+                    $matched = true;
                 }
             }
 
-            if ($match) {
+            if ($matched) {
                 continue;
             }
 
@@ -286,7 +284,7 @@ class RootPackageLoader extends ArrayLoader
      *
      * @return array<string, string>
      */
-    public static function extractReferences(array $requires, array $references)
+    public static function extractReferences(array $requires, array $references): array
     {
         foreach ($requires as $reqName => $reqVersion) {
             $reqVersion = Preg::replace('{^([^,\s@]+) as .+$}', '$1', $reqVersion);
