@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -30,7 +30,7 @@ class ClassMapGeneratorTest extends TestCase
      * @param string $directory
      * @param array<string, string> $expected
      */
-    public function testCreateMap($directory, $expected)
+    public function testCreateMap(string $directory, array $expected): void
     {
         $this->assertEqualsNormalized($expected, ClassMapGenerator::createMap($directory));
     }
@@ -38,12 +38,8 @@ class ClassMapGeneratorTest extends TestCase
     /**
      * @return array<array<string|array<string>>>
      */
-    public function getTestCreateMapTests()
+    public function getTestCreateMapTests(): array
     {
-        if (PHP_VERSION_ID == 50303) {
-            $this->markTestSkipped('Test segfaults on travis 5.3.3 due to ClassMap\LongString');
-        }
-
         $classmap = array(
             'Foo\\Bar\\A' => realpath(__DIR__) . '/Fixtures/classmap/sameNsMultipleClasses.php',
             'Foo\\Bar\\B' => realpath(__DIR__) . '/Fixtures/classmap/sameNsMultipleClasses.php',
@@ -91,21 +87,18 @@ class ClassMapGeneratorTest extends TestCase
             array(__DIR__ . '/Fixtures/template', array()),
         );
 
-        if (PHP_VERSION_ID >= 50400) {
-            $data[] = array(__DIR__ . '/Fixtures/php5.4', array(
-                'TFoo' => __DIR__ . '/Fixtures/php5.4/traits.php',
-                'CFoo' => __DIR__ . '/Fixtures/php5.4/traits.php',
-                'Foo\\TBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
-                'Foo\\IBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
-                'Foo\\TFooBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
-                'Foo\\CBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
-            ));
-        }
-        if (PHP_VERSION_ID >= 70000) {
-            $data[] = array(__DIR__ . '/Fixtures/php7.0', array(
-                'Dummy\Test\AnonClassHolder' => __DIR__ . '/Fixtures/php7.0/anonclass.php',
-            ));
-        }
+        $data[] = array(__DIR__ . '/Fixtures/php5.4', array(
+            'TFoo' => __DIR__ . '/Fixtures/php5.4/traits.php',
+            'CFoo' => __DIR__ . '/Fixtures/php5.4/traits.php',
+            'Foo\\TBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
+            'Foo\\IBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
+            'Foo\\TFooBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
+            'Foo\\CBar' => __DIR__ . '/Fixtures/php5.4/traits.php',
+        ));
+
+        $data[] = array(__DIR__ . '/Fixtures/php7.0', array(
+            'Dummy\Test\AnonClassHolder' => __DIR__ . '/Fixtures/php7.0/anonclass.php',
+        ));
 
         if (PHP_VERSION_ID >= 80100) {
             $data[] = array(__DIR__ . '/Fixtures/php8.1', array(
@@ -127,7 +120,7 @@ class ClassMapGeneratorTest extends TestCase
         return $data;
     }
 
-    public function testCreateMapFinderSupport()
+    public function testCreateMapFinderSupport(): void
     {
         $this->checkIfFinderIsAvailable();
 
@@ -140,21 +133,22 @@ class ClassMapGeneratorTest extends TestCase
         ), ClassMapGenerator::createMap($finder));
     }
 
-    public function testFindClassesThrowsWhenFileDoesNotExist()
+    public function testFindClassesThrowsWhenFileDoesNotExist(): void
     {
         $r = new \ReflectionClass('Composer\\Autoload\\ClassMapGenerator');
         $find = $r->getMethod('findClasses');
         $find->setAccessible(true);
 
-        $this->setExpectedException('RuntimeException', 'does not exist');
+        self::expectException('RuntimeException');
+        self::expectExceptionMessage('does not exist');
         $find->invoke(null, __DIR__ . '/no-file');
     }
 
-    public function testAmbiguousReference()
+    public function testAmbiguousReference(): void
     {
         $this->checkIfFinderIsAvailable();
 
-        $tempDir = $this->getUniqueTmpDirectory();
+        $tempDir = self::getUniqueTmpDirectory();
         $this->ensureDirectoryExistsAndClear($tempDir . '/other');
 
         $finder = new Finder();
@@ -173,7 +167,7 @@ class ClassMapGeneratorTest extends TestCase
 
         $io->expects($this->once())
             ->method('writeError')
-            ->will($this->returnCallback(function ($text) use (&$msg) {
+            ->will($this->returnCallback(function ($text) use (&$msg): void {
                 $msg = $text;
             }));
 
@@ -194,9 +188,9 @@ class ClassMapGeneratorTest extends TestCase
      * If one file has a class or interface defined more than once,
      * an ambiguous reference warning should not be produced
      */
-    public function testUnambiguousReference()
+    public function testUnambiguousReference(): void
     {
-        $tempDir = $this->getUniqueTmpDirectory();
+        $tempDir = self::getUniqueTmpDirectory();
 
         file_put_contents($tempDir . '/A.php', "<?php\nclass A {}");
         file_put_contents(
@@ -230,13 +224,14 @@ class ClassMapGeneratorTest extends TestCase
         $fs->removeDirectory($tempDir);
     }
 
-    public function testCreateMapThrowsWhenDirectoryDoesNotExist()
+    public function testCreateMapThrowsWhenDirectoryDoesNotExist(): void
     {
-        $this->setExpectedException('RuntimeException', 'Could not scan for classes inside');
+        self::expectException('RuntimeException');
+        self::expectExceptionMessage('Could not scan for classes inside');
         ClassMapGenerator::createMap(__DIR__ . '/no-file.no-foler');
     }
 
-    public function testDump()
+    public function testDump(): void
     {
         $tempDir = self::getUniqueTmpDirectory();
 
@@ -254,7 +249,7 @@ class ClassMapGeneratorTest extends TestCase
         $fs->removeDirectory($tempDir);
     }
 
-    public function testCreateMapDoesNotHitRegexBacktraceLimit()
+    public function testCreateMapDoesNotHitRegexBacktraceLimit(): void
     {
         $expected = array(
             'Foo\\StripNoise' => realpath(__DIR__) . '/Fixtures/pcrebacktracelimit/StripNoise.php',
@@ -279,7 +274,7 @@ class ClassMapGeneratorTest extends TestCase
      * @param string $message
      * @return  void
      */
-    protected function assertEqualsNormalized($expected, $actual, $message = '')
+    protected function assertEqualsNormalized(array $expected, array $actual, string $message = ''): void
     {
         foreach ($expected as $ns => $path) {
             $expected[$ns] = strtr($path, '\\', '/');
@@ -291,7 +286,7 @@ class ClassMapGeneratorTest extends TestCase
     }
 
     /** @return void */
-    private function checkIfFinderIsAvailable()
+    private function checkIfFinderIsAvailable(): void
     {
         if (!class_exists('Symfony\\Component\\Finder\\Finder')) {
             $this->markTestSkipped('Finder component is not available');
