@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,7 +17,7 @@ use Composer\Util\Filesystem;
 
 class CacheTest extends TestCase
 {
-    /** @var string[] */
+    /** @var array<\SplFileInfo> */
     private $files;
     /** @var string */
     private $root;
@@ -28,9 +28,9 @@ class CacheTest extends TestCase
     /** @var Cache&\PHPUnit\Framework\MockObject\MockObject */
     private $cache;
 
-    public function setUp()
+    public function setUp(): void
     {
-        $this->root = $this->getUniqueTmpDirectory();
+        $this->root = self::getUniqueTmpDirectory();
         $this->files = array();
         $zeros = str_repeat('0', 1000);
 
@@ -44,7 +44,7 @@ class CacheTest extends TestCase
 
         $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $this->cache = $this->getMockBuilder('Composer\Cache')
-            ->setMethods(array('getFinder'))
+            ->onlyMethods(array('getFinder'))
             ->setConstructorArgs(array($io, $this->root))
             ->getMock();
         $this->cache
@@ -53,15 +53,16 @@ class CacheTest extends TestCase
             ->will($this->returnValue($this->finder));
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         if (is_dir($this->root)) {
             $fs = new Filesystem;
             $fs->removeDirectory($this->root);
         }
     }
 
-    public function testRemoveOutdatedFiles()
+    public function testRemoveOutdatedFiles(): void
     {
         $outdated = array_slice($this->files, 1);
         $this->finder
@@ -81,7 +82,7 @@ class CacheTest extends TestCase
         $this->assertFileExists("{$this->root}/cached.file0.zip");
     }
 
-    public function testRemoveFilesWhenCacheIsTooLarge()
+    public function testRemoveFilesWhenCacheIsTooLarge(): void
     {
         $emptyFinder = $this->getMockBuilder('Symfony\Component\Finder\Finder')->disableOriginalConstructor()->getMock();
         $emptyFinder
@@ -110,7 +111,7 @@ class CacheTest extends TestCase
         $this->assertFileExists("{$this->root}/cached.file3.zip");
     }
 
-    public function testClearCache()
+    public function testClearCache(): void
     {
         $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $cache = new Cache($io, $this->root, 'a-z0-9.', $this->filesystem);
