@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -16,6 +16,7 @@ use Composer\Composer;
 use Composer\Config;
 use Composer\Script\Event as ScriptEvent;
 use Composer\Test\TestCase;
+use Composer\Util\Filesystem;
 
 class RunScriptCommandTest extends TestCase
 {
@@ -24,7 +25,7 @@ class RunScriptCommandTest extends TestCase
      * @param bool $dev
      * @param bool $noDev
      */
-    public function testDetectAndPassDevModeToEventAndToDispatching($dev, $noDev)
+    public function testDetectAndPassDevModeToEventAndToDispatching(bool $dev, bool $noDev): void
     {
         $scriptName = 'testScript';
 
@@ -47,6 +48,9 @@ class RunScriptCommandTest extends TestCase
             ->method('hasArgument')
             ->with('command')
             ->willReturn(false);
+        $input
+            ->method('isInteractive')
+            ->willReturn(false);
 
         $output = $this->getMockBuilder('Symfony\Component\Console\Output\OutputInterface')->getMock();
 
@@ -58,7 +62,7 @@ class RunScriptCommandTest extends TestCase
 
         $ed->expects($this->once())
             ->method('hasEventListeners')
-            ->with($this->callback(function (ScriptEvent $event) use ($scriptName, $expectedDevMode) {
+            ->with($this->callback(function (ScriptEvent $event) use ($scriptName, $expectedDevMode): bool {
                 return $event->getName() === $scriptName
                 && $event->isDevMode() === $expectedDevMode;
             }))
@@ -73,23 +77,43 @@ class RunScriptCommandTest extends TestCase
         $composer->setEventDispatcher($ed);
 
         $command = $this->getMockBuilder('Composer\Command\RunScriptCommand')
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'mergeApplicationDefinition',
-                'bind',
                 'getSynopsis',
                 'initialize',
-                'isInteractive',
-                'getComposer',
+                'requireComposer',
             ))
             ->getMock();
-        $command->expects($this->any())->method('getComposer')->willReturn($composer);
-        $command->method('isInteractive')->willReturn(false);
+        $command->expects($this->any())->method('requireComposer')->willReturn($composer);
 
         $command->run($input, $output);
     }
 
+    public function testCanListScripts(): void
+    {
+        $this->initTempComposer([
+            'scripts' => [
+                'test' => '@php test',
+                'fix-cs' => 'php-cs-fixer fix',
+            ],
+            'scripts-descriptions' => [
+                'fix-cs' => 'Run the codestyle fixer',
+            ],
+        ]);
+
+        $appTester = $this->getApplicationTester();
+        $appTester->run(['command' => 'run-script', '--list' => true]);
+
+        $appTester->assertCommandIsSuccessful();
+
+        $output = $appTester->getDisplay();
+
+        $this->assertStringContainsString('Runs the test script as defined in composer.json.', $output, 'The default description for the test script should be printed');
+        $this->assertStringContainsString('Run the codestyle fixer', $output, 'The custom description for the fix-cs script should be printed');
+    }
+
     /** @return bool[][] **/
-    public function getDevOptions()
+    public function getDevOptions(): array
     {
         return array(
             array(true, true),
@@ -100,7 +124,7 @@ class RunScriptCommandTest extends TestCase
     }
 
     /** @return Composer **/
-    private function createComposerInstance()
+    private function createComposerInstance(): Composer
     {
         $composer = new Composer;
         $config = new Config;
