@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -36,21 +36,21 @@ class InstallationManagerTest extends TestCase
      */
     protected $io;
 
-    public function setUp()
+    public function setUp(): void
     {
         $this->loop = $this->getMockBuilder('Composer\Util\Loop')->disableOriginalConstructor()->getMock();
         $this->repository = $this->getMockBuilder('Composer\Repository\InstalledRepositoryInterface')->getMock();
         $this->io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
     }
 
-    public function testAddGetInstaller()
+    public function testAddGetInstaller(): void
     {
         $installer = $this->createInstallerMock();
 
         $installer
             ->expects($this->exactly(2))
             ->method('supports')
-            ->will($this->returnCallback(function ($arg) {
+            ->will($this->returnCallback(function ($arg): bool {
                 return $arg === 'vendor';
             }));
 
@@ -59,18 +59,18 @@ class InstallationManagerTest extends TestCase
         $manager->addInstaller($installer);
         $this->assertSame($installer, $manager->getInstaller('vendor'));
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
         $manager->getInstaller('unregistered');
     }
 
-    public function testAddRemoveInstaller()
+    public function testAddRemoveInstaller(): void
     {
         $installer = $this->createInstallerMock();
 
         $installer
             ->expects($this->exactly(2))
             ->method('supports')
-            ->will($this->returnCallback(function ($arg) {
+            ->will($this->returnCallback(function ($arg): bool {
                 return $arg === 'vendor';
             }));
 
@@ -79,7 +79,7 @@ class InstallationManagerTest extends TestCase
         $installer2
             ->expects($this->exactly(1))
             ->method('supports')
-            ->will($this->returnCallback(function ($arg) {
+            ->will($this->returnCallback(function ($arg): bool {
                 return $arg === 'vendor';
             }));
 
@@ -93,11 +93,11 @@ class InstallationManagerTest extends TestCase
         $this->assertSame($installer, $manager->getInstaller('vendor'));
     }
 
-    public function testExecute()
+    public function testExecute(): void
     {
         $manager = $this->getMockBuilder('Composer\Installer\InstallationManager')
             ->setConstructorArgs(array($this->loop, $this->io))
-            ->setMethods(array('install', 'update', 'uninstall'))
+            ->onlyMethods(array('install', 'update', 'uninstall'))
             ->getMock();
 
         $installOperation = new InstallOperation($package = $this->createPackageMock());
@@ -128,7 +128,7 @@ class InstallationManagerTest extends TestCase
         $manager->execute($this->repository, array($installOperation, $removeOperation, $updateOperation));
     }
 
-    public function testInstall()
+    public function testInstall(): void
     {
         $installer = $this->createInstallerMock();
         $manager = new InstallationManager($this->loop, $this->io);
@@ -156,7 +156,7 @@ class InstallationManagerTest extends TestCase
         $manager->install($this->repository, $operation);
     }
 
-    public function testUpdateWithEqualTypes()
+    public function testUpdateWithEqualTypes(): void
     {
         $installer = $this->createInstallerMock();
         $manager = new InstallationManager($this->loop, $this->io);
@@ -189,7 +189,7 @@ class InstallationManagerTest extends TestCase
         $manager->update($this->repository, $operation);
     }
 
-    public function testUpdateWithNotEqualTypes()
+    public function testUpdateWithNotEqualTypes(): void
     {
         $libInstaller = $this->createInstallerMock();
         $bundleInstaller = $this->createInstallerMock();
@@ -212,7 +212,7 @@ class InstallationManagerTest extends TestCase
         $bundleInstaller
             ->expects($this->exactly(2))
             ->method('supports')
-            ->will($this->returnCallback(function ($arg) {
+            ->will($this->returnCallback(function ($arg): bool {
                 return $arg === 'bundles';
             }));
 
@@ -236,7 +236,7 @@ class InstallationManagerTest extends TestCase
         $manager->update($this->repository, $operation);
     }
 
-    public function testUninstall()
+    public function testUninstall(): void
     {
         $installer = $this->createInstallerMock();
         $manager = new InstallationManager($this->loop, $this->io);
@@ -264,7 +264,7 @@ class InstallationManagerTest extends TestCase
         $manager->uninstall($this->repository, $operation);
     }
 
-    public function testInstallBinary()
+    public function testInstallBinary(): void
     {
         $installer = $this->getMockBuilder('Composer\Installer\LibraryInstaller')
             ->disableOriginalConstructor()
