@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,6 @@ use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputOption;
 use Composer\IO\BufferIO;
-use Composer\Config;
 use Composer\Json\JsonFile;
 use Composer\Package\Dumper\ArrayDumper;
 use Composer\Util\Filesystem;
@@ -46,18 +45,19 @@ use Symfony\Component\Console\Formatter\OutputFormatter;
 class InstallerTest extends TestCase
 {
     /** @var string */
-    protected $prevCwd;
+    private $prevCwd;
     /** @var ?string */
     protected $tempComposerHome;
 
-    public function setUp()
+    public function setUp(): void
     {
-        $this->prevCwd = getcwd();
+        $this->prevCwd = Platform::getCwd();
         chdir(__DIR__);
     }
 
-    public function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         Platform::clearEnv('COMPOSER_POOL_OPTIMIZER');
 
         chdir($this->prevCwd);
@@ -73,7 +73,7 @@ class InstallerTest extends TestCase
      * @param RepositoryInterface[] $repositories
      * @param mixed[] $options
      */
-    public function testInstaller(RootPackageInterface $rootPackage, $repositories, array $options)
+    public function testInstaller(RootPackageInterface $rootPackage, array $repositories, array $options): void
     {
         $io = new BufferIO('', OutputInterface::VERBOSITY_NORMAL, new OutputFormatter(false));
 
@@ -121,13 +121,13 @@ class InstallerTest extends TestCase
             }));
         $lockJsonMock->expects($this->any())
             ->method('exists')
-            ->will($this->returnCallback(function () use (&$lockData) {
+            ->will($this->returnCallback(function () use (&$lockData): bool {
                 return $lockData !== null;
             }));
         $lockJsonMock->expects($this->any())
             ->method('write')
-            ->will($this->returnCallback(function ($value, $options = 0) use (&$lockData) {
-                $lockData = json_encode($value, JsonFile::JSON_PRETTY_PRINT);
+            ->will($this->returnCallback(function ($value, $options = 0) use (&$lockData): void {
+                $lockData = json_encode($value, JSON_PRETTY_PRINT);
             }));
 
         $tempLockData = null;
@@ -141,9 +141,9 @@ class InstallerTest extends TestCase
         $output = str_replace("\r", '', $io->getOutput());
         $this->assertEquals(0, $result, $output);
 
-        $expectedInstalled = isset($options['install']) ? $options['install'] : array();
-        $expectedUpdated = isset($options['update']) ? $options['update'] : array();
-        $expectedUninstalled = isset($options['uninstall']) ? $options['uninstall'] : array();
+        $expectedInstalled = $options['install'] ?? array();
+        $expectedUpdated = $options['update'] ?? array();
+        $expectedUninstalled = $options['uninstall'] ?? array();
 
         $installed = $installationManager->getInstalledPackages();
         $this->assertEquals($this->makePackagesComparable($expectedInstalled), $this->makePackagesComparable($installed));
@@ -159,7 +159,7 @@ class InstallerTest extends TestCase
      * @param  PackageInterface[] $packages
      * @return mixed[]
      */
-    protected function makePackagesComparable($packages)
+    protected function makePackagesComparable(array $packages): array
     {
         $dumper = new ArrayDumper();
 
@@ -171,7 +171,7 @@ class InstallerTest extends TestCase
         return $comparable;
     }
 
-    public function provideInstaller()
+    public function provideInstaller(): array
     {
         $cases = array();
 
@@ -189,7 +189,7 @@ class InstallerTest extends TestCase
 
         $cases[] = array(
             $a,
-            new ArrayRepository(array($b)),
+            [new ArrayRepository(array($b))],
             array(
                 'install' => array($b),
             ),
@@ -209,7 +209,7 @@ class InstallerTest extends TestCase
 
         $cases[] = array(
             $a,
-            new ArrayRepository(array($a, $b)),
+            [new ArrayRepository(array($a, $b))],
             array(
                 'install' => array($b),
             ),
@@ -224,19 +224,19 @@ class InstallerTest extends TestCase
      * @dataProvider provideSlowIntegrationTests
      * @param string $file
      * @param string $message
-     * @param ?string $condition
-     * @param Config $composerConfig
-     * @param ?mixed[] $lock
-     * @param ?mixed[] $installed
+     * @param null|string $condition
+     * @param mixed[] $composerConfig
+     * @param ?array<mixed> $lock
+     * @param ?array<mixed> $installed
      * @param string $run
      * @param mixed[]|false $expectLock
-     * @param ?mixed[] $expectInstalled
-     * @param ?string $expectOutput
-     * @param ?string $expectOutputOptimized
+     * @param ?array<mixed> $expectInstalled
+     * @param null|string $expectOutput
+     * @param null|string $expectOutputOptimized
      * @param string $expect
-     * @param int|string $expectResult
+     * @param int|class-string<\Throwable> $expectResult
      */
-    public function testSlowIntegration($file, $message, $condition, $composerConfig, $lock, $installed, $run, $expectLock, $expectInstalled, $expectOutput, $expectOutputOptimized, $expect, $expectResult)
+    public function testSlowIntegration(string $file, string $message, ?string $condition, array $composerConfig, ?array $lock, ?array $installed, string $run, $expectLock, ?array $expectInstalled, ?string $expectOutput, ?string $expectOutputOptimized, string $expect, $expectResult): void
     {
         Platform::putEnv('COMPOSER_POOL_OPTIMIZER', '0');
 
@@ -247,19 +247,19 @@ class InstallerTest extends TestCase
      * @dataProvider provideIntegrationTests
      * @param string $file
      * @param string $message
-     * @param ?string $condition
-     * @param Config $composerConfig
-     * @param ?mixed[] $lock
-     * @param ?mixed[] $installed
+     * @param null|string $condition
+     * @param mixed[] $composerConfig
+     * @param ?array<mixed> $lock
+     * @param ?array<mixed> $installed
      * @param string $run
      * @param mixed[]|false $expectLock
-     * @param ?mixed[] $expectInstalled
-     * @param ?string $expectOutput
-     * @param ?string $expectOutputOptimized
+     * @param ?array<mixed> $expectInstalled
+     * @param null|string $expectOutput
+     * @param null|string $expectOutputOptimized
      * @param string $expect
-     * @param int|string $expectResult
+     * @param int|class-string<\Throwable> $expectResult
      */
-    public function testIntegrationWithPoolOptimizer($file, $message, $condition, $composerConfig, $lock, $installed, $run, $expectLock, $expectInstalled, $expectOutput, $expectOutputOptimized, $expect, $expectResult)
+    public function testIntegrationWithPoolOptimizer(string $file, string $message, ?string $condition, array $composerConfig, ?array $lock, ?array $installed, string $run, $expectLock, ?array $expectInstalled, ?string $expectOutput, ?string $expectOutputOptimized, string $expect, $expectResult): void
     {
         Platform::putEnv('COMPOSER_POOL_OPTIMIZER', '1');
 
@@ -270,19 +270,19 @@ class InstallerTest extends TestCase
      * @dataProvider provideIntegrationTests
      * @param string $file
      * @param string $message
-     * @param ?string $condition
-     * @param Config $composerConfig
-     * @param ?mixed[] $lock
-     * @param ?mixed[] $installed
+     * @param null|string $condition
+     * @param mixed[] $composerConfig
+     * @param ?array<mixed> $lock
+     * @param ?array<mixed> $installed
      * @param string $run
      * @param mixed[]|false $expectLock
-     * @param ?mixed[] $expectInstalled
-     * @param ?string $expectOutput
-     * @param ?string $expectOutputOptimized
+     * @param ?array<mixed> $expectInstalled
+     * @param null|string $expectOutput
+     * @param null|string $expectOutputOptimized
      * @param string $expect
-     * @param int|string $expectResult
+     * @param int|class-string<\Throwable> $expectResult
      */
-    public function testIntegrationWithRawPool($file, $message, $condition, $composerConfig, $lock, $installed, $run, $expectLock, $expectInstalled, $expectOutput, $expectOutputOptimized, $expect, $expectResult)
+    public function testIntegrationWithRawPool(string $file, string $message, ?string $condition, array $composerConfig, ?array $lock, ?array $installed, string $run, $expectLock, ?array $expectInstalled, ?string $expectOutput, ?string $expectOutputOptimized, string $expect, $expectResult): void
     {
         Platform::putEnv('COMPOSER_POOL_OPTIMIZER', '0');
 
@@ -292,23 +292,23 @@ class InstallerTest extends TestCase
     /**
      * @param string $file
      * @param string $message
-     * @param ?string $condition
-     * @param Config $composerConfig
-     * @param ?mixed[] $lock
-     * @param ?mixed[] $installed
+     * @param null|string $condition
+     * @param mixed[] $composerConfig
+     * @param ?array<mixed> $lock
+     * @param ?array<mixed> $installed
      * @param string $run
      * @param mixed[]|false $expectLock
-     * @param ?mixed[] $expectInstalled
-     * @param ?string $expectOutput
+     * @param ?array<mixed> $expectInstalled
+     * @param null|string $expectOutput
      * @param string $expect
-     * @param int|string $expectResult
+     * @param int|class-string<\Throwable> $expectResult
      * @return void
      */
-    private function doTestIntegration($file, $message, $condition, $composerConfig, $lock, $installed, $run, $expectLock, $expectInstalled, $expectOutput, $expect, $expectResult)
+    private function doTestIntegration(string $file, string $message, ?string $condition, array $composerConfig, ?array $lock, ?array $installed, string $run, $expectLock, ?array $expectInstalled, ?string $expectOutput, string $expect, $expectResult): void
     {
         if ($condition) {
             eval('$res = '.$condition.';');
-            if (!$res) {
+            if (!$res) { // @phpstan-ignore-line
                 $this->markTestSkipped($condition);
             }
         }
@@ -318,7 +318,8 @@ class InstallerTest extends TestCase
         // Prepare for exceptions
         if (!is_int($expectResult)) {
             $normalizedOutput = rtrim(str_replace("\n", PHP_EOL, $expect));
-            $this->setExpectedException($expectResult, $normalizedOutput);
+            self::expectException($expectResult);
+            self::expectExceptionMessage($normalizedOutput);
         }
 
         // Create Composer mock object according to configuration
@@ -337,7 +338,7 @@ class InstallerTest extends TestCase
         $repositoryManager->setLocalRepository(new InstalledFilesystemRepositoryMock($jsonMock));
 
         // emulate a writable lock file
-        $lockData = $lock ? json_encode($lock, JsonFile::JSON_PRETTY_PRINT) : null;
+        $lockData = $lock ? json_encode($lock, JSON_PRETTY_PRINT) : null;
         $lockJsonMock = $this->getMockBuilder('Composer\Json\JsonFile')->disableOriginalConstructor()->getMock();
         $lockJsonMock->expects($this->any())
             ->method('read')
@@ -346,20 +347,20 @@ class InstallerTest extends TestCase
             }));
         $lockJsonMock->expects($this->any())
             ->method('exists')
-            ->will($this->returnCallback(function () use (&$lockData) {
+            ->will($this->returnCallback(function () use (&$lockData): bool {
                 return $lockData !== null;
             }));
         $lockJsonMock->expects($this->any())
             ->method('write')
-            ->will($this->returnCallback(function ($value, $options = 0) use (&$lockData) {
-                $lockData = json_encode($value, JsonFile::JSON_PRETTY_PRINT);
+            ->will($this->returnCallback(function ($value, $options = 0) use (&$lockData): void {
+                $lockData = json_encode($value, JSON_PRETTY_PRINT);
             }));
 
         if ($expectLock) {
             $actualLock = array();
             $lockJsonMock->expects($this->atLeastOnce())
                 ->method('write')
-                ->will($this->returnCallback(function ($hash, $options) use (&$actualLock) {
+                ->will($this->returnCallback(function ($hash, $options) use (&$actualLock): void {
                     // need to do assertion outside of mock for nice phpunit output
                     // so store value temporarily in reference for later assetion
                     $actualLock = $hash;
@@ -388,7 +389,7 @@ class InstallerTest extends TestCase
         $install->addOption('ignore-platform-req', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY);
         $install->addOption('no-dev', null, InputOption::VALUE_NONE);
         $install->addOption('dry-run', null, InputOption::VALUE_NONE);
-        $install->setCode(function ($input, $output) use ($installer) {
+        $install->setCode(function ($input, $output) use ($installer): int {
             $ignorePlatformReqs = $input->getOption('ignore-platform-reqs') ?: ($input->getOption('ignore-platform-req') ?: false);
 
             $installer
@@ -412,9 +413,9 @@ class InstallerTest extends TestCase
         $update->addOption('prefer-stable', null, InputOption::VALUE_NONE);
         $update->addOption('prefer-lowest', null, InputOption::VALUE_NONE);
         $update->addArgument('packages', InputArgument::IS_ARRAY | InputArgument::OPTIONAL);
-        $update->setCode(function ($input, $output) use ($installer) {
+        $update->setCode(function ($input, $output) use ($installer): int {
             $packages = $input->getArgument('packages');
-            $filteredPackages = array_filter($packages, function ($package) {
+            $filteredPackages = array_filter($packages, function ($package): bool {
                 return !in_array($package, array('lock', 'nothing', 'mirrors'), true);
             });
             $updateMirrors = $input->getOption('lock') || count($filteredPackages) != count($packages);
@@ -451,6 +452,9 @@ class InstallerTest extends TestCase
 
         $application->setAutoExit(false);
         $appOutput = fopen('php://memory', 'w+');
+        if (false === $appOutput) {
+            self::fail('Failed to open memory stream');
+        }
         $input = new StringInput($run.' -vvv');
         $input->setInteractive(false);
         $result = $application->run($input, new StreamOutput($appOutput));
@@ -478,7 +482,7 @@ class InstallerTest extends TestCase
                 $actualInstalled[] = $package;
             }
 
-            usort($actualInstalled, function ($a, $b) {
+            usort($actualInstalled, function ($a, $b): int {
                 return strcmp($a['name'], $b['name']);
             });
 
@@ -497,12 +501,12 @@ class InstallerTest extends TestCase
         }
     }
 
-    public function provideSlowIntegrationTests()
+    public function provideSlowIntegrationTests(): array
     {
         return $this->loadIntegrationTests('installer-slow/');
     }
 
-    public function provideIntegrationTests()
+    public function provideIntegrationTests(): array
     {
         return $this->loadIntegrationTests('installer/');
     }
@@ -511,12 +515,14 @@ class InstallerTest extends TestCase
      * @param  string $path
      * @return mixed[]
      */
-    public function loadIntegrationTests($path)
+    public function loadIntegrationTests(string $path): array
     {
         $fixturesDir = realpath(__DIR__.'/Fixtures/'.$path);
         $tests = array();
 
         foreach (new \RecursiveIteratorIterator(new \RecursiveDirectoryIterator($fixturesDir), \RecursiveIteratorIterator::LEAVES_ONLY) as $file) {
+            $file = (string) $file;
+
             if (!Preg::isMatch('/\.test$/', $file)) {
                 continue;
             }
@@ -553,7 +559,7 @@ class InstallerTest extends TestCase
                 if (!empty($testData['LOCK'])) {
                     $lock = JsonFile::parseJson($testData['LOCK']);
                     if (!isset($lock['hash'])) {
-                        $lock['hash'] = md5(json_encode($composer));
+                        $lock['hash'] = md5(JsonFile::encode($composer, 0));
                     }
                 }
                 if (!empty($testData['INSTALLED'])) {
@@ -570,8 +576,8 @@ class InstallerTest extends TestCase
                 if (!empty($testData['EXPECT-INSTALLED'])) {
                     $expectInstalled = JsonFile::parseJson($testData['EXPECT-INSTALLED']);
                 }
-                $expectOutput = isset($testData['EXPECT-OUTPUT']) ? $testData['EXPECT-OUTPUT'] : null;
-                $expectOutputOptimized = isset($testData['EXPECT-OUTPUT-OPTIMIZED']) ? $testData['EXPECT-OUTPUT-OPTIMIZED'] : null;
+                $expectOutput = $testData['EXPECT-OUTPUT'] ?? null;
+                $expectOutputOptimized = $testData['EXPECT-OUTPUT-OPTIMIZED'] ?? null;
                 $expect = $testData['EXPECT'];
                 if (!empty($testData['EXPECT-EXCEPTION'])) {
                     $expectResult = $testData['EXPECT-EXCEPTION'];
@@ -594,12 +600,11 @@ class InstallerTest extends TestCase
     }
 
     /**
-     * @param  string $fixturesDir
      * @return mixed[]
      */
-    protected function readTestFile(\SplFileInfo $file, $fixturesDir)
+    protected function readTestFile(string $file, string $fixturesDir): array
     {
-        $tokens = Preg::split('#(?:^|\n*)--([A-Z-]+)--\n#', file_get_contents($file->getRealPath()), -1, PREG_SPLIT_DELIM_CAPTURE);
+        $tokens = Preg::split('#(?:^|\n*)--([A-Z-]+)--\n#', file_get_contents($file), -1, PREG_SPLIT_DELIM_CAPTURE);
 
         $sectionInfo = array(
             'TEST' => true,
