@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -33,13 +33,13 @@ class ArchivableFilesFinderTest extends TestCase
      */
     protected $fs;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $fs = new Filesystem;
         $this->fs = $fs;
 
         $this->sources = $fs->normalizePath(
-            $this->getUniqueTmpDirectory()
+            self::getUniqueTmpDirectory()
         );
 
         $fileTree = array(
@@ -96,13 +96,14 @@ class ArchivableFilesFinderTest extends TestCase
         }
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         $fs = new Filesystem;
         $fs->removeDirectory($this->sources);
     }
 
-    public function testManualExcludes()
+    public function testManualExcludes(): void
     {
         $excludes = array(
             'prefixB.foo',
@@ -155,7 +156,7 @@ class ArchivableFilesFinderTest extends TestCase
         ));
     }
 
-    public function testGitExcludes()
+    public function testGitExcludes(): void
     {
         $this->skipIfNotExecutable('git');
 
@@ -203,7 +204,7 @@ class ArchivableFilesFinderTest extends TestCase
         ));
     }
 
-    public function testSkipExcludes()
+    public function testSkipExcludes(): void
     {
         $excludes = array(
             'prefixB.foo',
@@ -262,7 +263,7 @@ class ArchivableFilesFinderTest extends TestCase
     /**
      * @return string[]
      */
-    protected function getArchivableFiles()
+    protected function getArchivableFiles(): array
     {
         $files = array();
         foreach ($this->finder as $file) {
@@ -281,14 +282,9 @@ class ArchivableFilesFinderTest extends TestCase
      *
      * @return string[]
      */
-    protected function getArchivedFiles($command)
+    protected function getArchivedFiles(string $command): array
     {
-        if (method_exists('Symfony\Component\Process\Process', 'fromShellCommandline')) {
-            $process = Process::fromShellCommandline($command, $this->sources);
-        } else {
-            // @phpstan-ignore-next-line symfony/process 2.8 accepts a string but not 5.3 which is used only for PHPStan
-            $process = new Process($command, $this->sources);
-        }
+        $process = Process::fromShellCommandline($command, $this->sources);
         $process->run();
 
         $archive = new \PharData($this->sources.'/archive.zip');
@@ -296,7 +292,7 @@ class ArchivableFilesFinderTest extends TestCase
 
         $files = array();
         foreach ($iterator as $file) {
-            $files[] = Preg::replace('#^phar://'.preg_quote($this->sources, '#').'/archive\.zip/archive#', '', $this->fs->normalizePath($file));
+            $files[] = Preg::replace('#^phar://'.preg_quote($this->sources, '#').'/archive\.zip/archive#', '', $this->fs->normalizePath((string) $file));
         }
 
         unset($archive, $iterator, $file);
@@ -310,7 +306,7 @@ class ArchivableFilesFinderTest extends TestCase
      *
      * @return void
      */
-    protected function assertArchivableFiles($expectedFiles)
+    protected function assertArchivableFiles(array $expectedFiles): void
     {
         $actualFiles = $this->getArchivableFiles();
 
