@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -20,8 +20,7 @@ use Composer\Package\RootPackage;
 use Composer\Package\Version\VersionGuesser;
 use Composer\Semver\VersionParser;
 use Composer\Test\TestCase;
-use Composer\Test\Mock\ProcessExecutorMock;
-use Prophecy\Argument;
+use Composer\Util\ProcessExecutor;
 
 class RootPackageLoaderTest extends TestCase
 {
@@ -30,7 +29,7 @@ class RootPackageLoaderTest extends TestCase
      *
      * @return RootPackage|RootAliasPackage
      */
-    protected function loadPackage($data)
+    protected function loadPackage(array $data): \Composer\Package\PackageInterface
     {
         $manager = $this->getMockBuilder('Composer\\Repository\\RepositoryManager')
             ->disableOriginalConstructor()
@@ -38,13 +37,16 @@ class RootPackageLoaderTest extends TestCase
 
         $config = new Config;
         $config->merge(array('repositories' => array('packagist' => false)));
+        $processExecutor = new ProcessExecutor();
+        $processExecutor->enableAsync();
+        $guesser = new VersionGuesser($config, $processExecutor, new VersionParser());
 
-        $loader = new RootPackageLoader($manager, $config);
+        $loader = new RootPackageLoader($manager, $config, null, $guesser);
 
         return $loader->load($data);
     }
 
-    public function testStabilityFlagsParsing()
+    public function testStabilityFlagsParsing(): void
     {
         $package = $this->loadPackage(array(
             'require' => array(
@@ -72,7 +74,7 @@ class RootPackageLoaderTest extends TestCase
         ), $package->getStabilityFlags());
     }
 
-    public function testNoVersionIsVisibleInPrettyVersion()
+    public function testNoVersionIsVisibleInPrettyVersion(): void
     {
         $manager = $this->getMockBuilder('Composer\\Repository\\RepositoryManager')
             ->disableOriginalConstructor()
@@ -81,7 +83,7 @@ class RootPackageLoaderTest extends TestCase
 
         $config = new Config;
         $config->merge(array('repositories' => array('packagist' => false)));
-        $loader = new RootPackageLoader($manager, $config, null, new VersionGuesser($config, $process = new ProcessExecutorMock, new VersionParser()));
+        $loader = new RootPackageLoader($manager, $config, null, new VersionGuesser($config, $process = $this->getProcessExecutorMock(), new VersionParser()));
         $process->expects(array(), false, array('return' => 1));
 
         $package = $loader->load(array());
@@ -90,12 +92,13 @@ class RootPackageLoaderTest extends TestCase
         $this->assertEquals(RootPackage::DEFAULT_PRETTY_VERSION, $package->getPrettyVersion());
     }
 
-    public function testPrettyVersionForRootPackageInVersionBranch()
+    public function testPrettyVersionForRootPackageInVersionBranch(): void
     {
         // see #6845
-        $manager = $this->prophesize('Composer\\Repository\\RepositoryManager');
-        $versionGuesser = $this->prophesize('Composer\\Package\\Version\\VersionGuesser');
-        $versionGuesser->guessVersion(Argument::cetera())
+        $manager = $this->getMockBuilder('Composer\\Repository\\RepositoryManager')->disableOriginalConstructor()->getMock();
+        $versionGuesser = $this->getMockBuilder('Composer\\Package\\Version\\VersionGuesser')->disableOriginalConstructor()->getMock();
+        $versionGuesser->expects($this->atLeastOnce())
+            ->method('guessVersion')
             ->willReturn(array(
                 'name' => 'A',
                 'version' => '3.0.9999999.9999999-dev',
@@ -104,13 +107,13 @@ class RootPackageLoaderTest extends TestCase
             ));
         $config = new Config;
         $config->merge(array('repositories' => array('packagist' => false)));
-        $loader = new RootPackageLoader($manager->reveal(), $config, null, $versionGuesser->reveal());
+        $loader = new RootPackageLoader($manager, $config, null, $versionGuesser);
         $package = $loader->load(array());
 
         $this->assertEquals('3.0-dev', $package->getPrettyVersion());
     }
 
-    public function testFeatureBranchPrettyVersion()
+    public function testFeatureBranchPrettyVersion(): void
     {
         if (!function_exists('proc_open')) {
             $this->markTestSkipped('proc_open() is not available');
@@ -121,10 +124,10 @@ class RootPackageLoaderTest extends TestCase
             ->getMock()
         ;
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* latest-production 38137d2f6c70e775e137b2d8a7a7d3eaebf7c7e5 Commit message\n  master 4f6ed96b0bc363d2aa4404c3412de1c011f67c66 Commit message\n",
             ),
             'git rev-list master..latest-production',
@@ -136,11 +139,9 @@ class RootPackageLoaderTest extends TestCase
         $package = $loader->load(array('require' => array('foo/bar' => 'self.version')));
 
         $this->assertEquals("dev-master", $package->getPrettyVersion());
-
-        $process->assertComplete($this);
     }
 
-    public function testNonFeatureBranchPrettyVersion()
+    public function testNonFeatureBranchPrettyVersion(): void
     {
         if (!function_exists('proc_open')) {
             $this->markTestSkipped('proc_open() is not available');
@@ -151,10 +152,10 @@ class RootPackageLoaderTest extends TestCase
             ->getMock()
         ;
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* latest-production 38137d2f6c70e775e137b2d8a7a7d3eaebf7c7e5 Commit message\n  master 4f6ed96b0bc363d2aa4404c3412de1c011f67c66 Commit message\n",
             ),
         ), true);
@@ -165,7 +166,5 @@ class RootPackageLoaderTest extends TestCase
         $package = $loader->load(array('require' => array('foo/bar' => 'self.version'), "non-feature-branches" => array("latest-.*")));
 
         $this->assertEquals("dev-latest-production", $package->getPrettyVersion());
-
-        $process->assertComplete($this);
     }
 }
