@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -18,24 +18,23 @@ use Composer\Semver\VersionParser;
 use Composer\Test\TestCase;
 use Composer\Util\Git as GitUtil;
 use Composer\Util\ProcessExecutor;
-use Composer\Test\Mock\ProcessExecutorMock;
 
 class VersionGuesserTest extends TestCase
 {
-    public function setUp()
+    public function setUp(): void
     {
         if (!function_exists('proc_open')) {
             $this->markTestSkipped('proc_open() is not available');
         }
     }
 
-    public function testHgGuessVersionReturnsData()
+    public function testHgGuessVersionReturnsData(): void
     {
         $branch = 'default';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
-            array('cmd' => 'git branch -a --no-color --no-abbrev -v', 'return' => 128),
+            array('cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'], 'return' => 128),
             array('cmd' => 'git describe --exact-match --tags', 'return' => 128),
             array('cmd' => 'git log --pretty="%H" -n1 HEAD'.GitUtil::getNoShowSignatureFlag($process), 'return' => 128),
             array('cmd' => 'hg branch', 'return' => 0, 'stdout' => $branch),
@@ -53,19 +52,17 @@ class VersionGuesserTest extends TestCase
         $this->assertEquals("dev-".$branch, $versionArray['version']);
         $this->assertEquals("dev-".$branch, $versionArray['pretty_version']);
         $this->assertEmpty($versionArray['commit']);
-
-        $process->assertComplete($this);
     }
 
-    public function testGuessVersionReturnsData()
+    public function testGuessVersionReturnsData(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
         $anotherCommitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* master $commitHash Commit message\n(no branch) $anotherCommitHash Commit message\n",
             ),
         ), true);
@@ -80,19 +77,17 @@ class VersionGuesserTest extends TestCase
         $this->assertArrayNotHasKey('feature_version', $versionArray);
         $this->assertArrayNotHasKey('feature_pretty_version', $versionArray);
         $this->assertEquals($commitHash, $versionArray['commit']);
-
-        $process->assertComplete($this);
     }
 
-    public function testGuessVersionDoesNotSeeCustomDefaultBranchAsNonFeatureBranch()
+    public function testGuessVersionDoesNotSeeCustomDefaultBranchAsNonFeatureBranch(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
         $anotherCommitHash = '13a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 // Assumption here is that arbitrary would be the default branch
                 'stdout' => "  arbitrary $commitHash Commit message\n* current $anotherCommitHash Another message\n",
             ),
@@ -105,19 +100,17 @@ class VersionGuesserTest extends TestCase
 
         $this->assertEquals("dev-current", $versionArray['version']);
         $this->assertEquals($anotherCommitHash, $versionArray['commit']);
-
-        $process->assertComplete($this);
     }
 
-    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNaming()
+    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNaming(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
         $anotherCommitHash = '13a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "  arbitrary $commitHash Commit message\n* feature $anotherCommitHash Another message\n",
             ),
             array(
@@ -135,19 +128,17 @@ class VersionGuesserTest extends TestCase
         $this->assertEquals($anotherCommitHash, $versionArray['commit']);
         $this->assertEquals("dev-feature", $versionArray['feature_version']);
         $this->assertEquals("dev-feature", $versionArray['feature_pretty_version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNamingRegex()
+    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNamingRegex(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
         $anotherCommitHash = '13a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "  latest-testing $commitHash Commit message\n* feature $anotherCommitHash Another message\n",
             ),
             array(
@@ -165,19 +156,17 @@ class VersionGuesserTest extends TestCase
         $this->assertEquals($anotherCommitHash, $versionArray['commit']);
         $this->assertEquals("dev-feature", $versionArray['feature_version']);
         $this->assertEquals("dev-feature", $versionArray['feature_pretty_version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNamingWhenOnNonFeatureBranch()
+    public function testGuessVersionReadsAndRespectsNonFeatureBranchesConfigurationForArbitraryNamingWhenOnNonFeatureBranch(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
         $anotherCommitHash = '13a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* latest-testing $commitHash Commit message\n  current $anotherCommitHash Another message\n  master $anotherCommitHash Another message\n",
             ),
         ), true);
@@ -191,18 +180,16 @@ class VersionGuesserTest extends TestCase
         $this->assertEquals($commitHash, $versionArray['commit']);
         $this->assertArrayNotHasKey('feature_version', $versionArray);
         $this->assertArrayNotHasKey('feature_pretty_version', $versionArray);
-
-        $process->assertComplete($this);
     }
 
-    public function testDetachedHeadBecomesDevHash()
+    public function testDetachedHeadBecomesDevHash(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* (no branch) $commitHash Commit message\n",
             ),
             'git describe --exact-match --tags',
@@ -214,18 +201,16 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array(), 'dummy/path');
 
         $this->assertEquals("dev-$commitHash", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testDetachedFetchHeadBecomesDevHashGit2()
+    public function testDetachedFetchHeadBecomesDevHashGit2(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* (HEAD detached at FETCH_HEAD) $commitHash Commit message\n",
             ),
             'git describe --exact-match --tags',
@@ -237,18 +222,16 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array(), 'dummy/path');
 
         $this->assertEquals("dev-$commitHash", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testDetachedCommitHeadBecomesDevHashGit2()
+    public function testDetachedCommitHeadBecomesDevHashGit2(): void
     {
         $commitHash = '03a15d220da53c52eddd5f32ffca64a7b3801bea';
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* (HEAD detached at 03a15d220) $commitHash Commit message\n",
             ),
             'git describe --exact-match --tags',
@@ -260,16 +243,14 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array(), 'dummy/path');
 
         $this->assertEquals("dev-$commitHash", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testTagBecomesVersion()
+    public function testTagBecomesVersion(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* (HEAD detached at v2.0.5-alpha2) 433b98d4218c181bae01865901aac045585e8a1a Commit message\n",
             ),
             array(
@@ -284,16 +265,14 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array(), 'dummy/path');
 
         $this->assertEquals("2.0.5.0-alpha2", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testTagBecomesPrettyVersion()
+    public function testTagBecomesPrettyVersion(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* (HEAD detached at 1.0.0) c006f0c12bbbf197b5c071ffb1c0e9812bb14a4d Commit message\n",
             ),
             array(
@@ -309,16 +288,14 @@ class VersionGuesserTest extends TestCase
 
         $this->assertEquals('1.0.0.0', $versionData['version']);
         $this->assertEquals('1.0.0', $versionData['pretty_version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testInvalidTagBecomesVersion()
+    public function testInvalidTagBecomesVersion(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* foo 03a15d220da53c52eddd5f32ffca64a7b3801bea Commit message\n",
             ),
         ), true);
@@ -329,16 +306,14 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array(), 'dummy/path');
 
         $this->assertEquals("dev-foo", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testNumericBranchesShowNicely()
+    public function testNumericBranchesShowNicely(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* 1.5 03a15d220da53c52eddd5f32ffca64a7b3801bea Commit message\n",
             ),
         ), true);
@@ -350,16 +325,14 @@ class VersionGuesserTest extends TestCase
 
         $this->assertEquals("1.5.x-dev", $versionData['pretty_version']);
         $this->assertEquals("1.5.9999999.9999999-dev", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 
-    public function testRemoteBranchesAreSelected()
+    public function testRemoteBranchesAreSelected(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
-                'cmd' => 'git branch -a --no-color --no-abbrev -v',
+                'cmd' => ['git', 'branch', '-a', '--no-color', '--no-abbrev', '-v'],
                 'stdout' => "* feature-branch 03a15d220da53c52eddd5f32ffca64a7b3801bea Commit message\n".
                         "remotes/origin/1.5 03a15d220da53c52eddd5f32ffca64a7b3801bea Commit message\n",
             ),
@@ -375,7 +348,5 @@ class VersionGuesserTest extends TestCase
         $versionData = $guesser->guessVersion(array('version' => 'self.version'), 'dummy/path');
         $this->assertEquals("1.5.x-dev", $versionData['pretty_version']);
         $this->assertEquals("1.5.9999999.9999999-dev", $versionData['version']);
-
-        $process->assertComplete($this);
     }
 }
