@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,6 +13,7 @@
 namespace Composer\Test\Repository;
 
 use Composer\Test\TestCase;
+use Composer\Util\Platform;
 use Symfony\Component\Process\ExecutableFinder;
 use Composer\Package\Dumper\ArrayDumper;
 use Composer\Repository\VcsRepository;
@@ -42,7 +43,7 @@ class VcsRepositoryTest extends TestCase
     /**
      * @return void
      */
-    protected function initialize()
+    protected function initialize(): void
     {
         $locator = new ExecutableFinder();
         if (!$locator->find('git')) {
@@ -51,9 +52,9 @@ class VcsRepositoryTest extends TestCase
             return;
         }
 
-        $oldCwd = getcwd();
-        self::$composerHome = $this->getUniqueTmpDirectory();
-        self::$gitRepo = $this->getUniqueTmpDirectory();
+        $oldCwd = Platform::getCwd();
+        self::$composerHome = self::getUniqueTmpDirectory();
+        self::$gitRepo = self::getUniqueTmpDirectory();
 
         if (!@chdir(self::$gitRepo)) {
             $this->skipped = 'Could not move into the temp git repo '.self::$gitRepo;
@@ -63,8 +64,8 @@ class VcsRepositoryTest extends TestCase
 
         // init
         $process = new ProcessExecutor;
-        $exec = function ($command) use ($process) {
-            $cwd = getcwd();
+        $exec = function ($command) use ($process): void {
+            $cwd = Platform::getCwd();
             if ($process->execute($command, $output, $cwd) !== 0) {
                 throw new \RuntimeException('Failed to execute '.$command.': '.$process->getErrorOutput());
             }
@@ -130,7 +131,7 @@ class VcsRepositoryTest extends TestCase
         chdir($oldCwd);
     }
 
-    public function setUp()
+    public function setUp(): void
     {
         if (!self::$gitRepo) {
             $this->initialize();
@@ -140,14 +141,14 @@ class VcsRepositoryTest extends TestCase
         }
     }
 
-    public static function tearDownAfterClass()
+    public static function tearDownAfterClass(): void
     {
         $fs = new Filesystem;
         $fs->removeDirectory(self::$composerHome);
         $fs->removeDirectory(self::$gitRepo);
     }
 
-    public function testLoadVersions()
+    public function testLoadVersions(): void
     {
         $expected = array(
             '0.6.0' => true,
