@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -12,14 +12,20 @@
 
 namespace Composer\Test;
 
+use Composer\Config;
+use Composer\Console\Application;
+use Composer\IO\IOInterface;
+use Composer\Json\JsonFile;
 use Composer\Pcre\Preg;
 use Composer\Semver\VersionParser;
-use Composer\Package\RootPackageInterface;
 use Composer\Package\PackageInterface;
 use Composer\Semver\Constraint\Constraint;
+use Composer\Test\Mock\HttpDownloaderMock;
+use Composer\Test\Mock\ProcessExecutorMock;
 use Composer\Util\Filesystem;
 use Composer\Util\Platform;
 use Composer\Util\Silencer;
+use Symfony\Component\Console\Tester\ApplicationTester;
 use Symfony\Component\Process\ExecutableFinder;
 use Composer\Package\Loader\ArrayLoader;
 use Composer\Package\BasePackage;
@@ -28,10 +34,10 @@ use Composer\Package\AliasPackage;
 use Composer\Package\RootAliasPackage;
 use Composer\Package\CompletePackage;
 use Composer\Package\CompleteAliasPackage;
-use Composer\Package\CompletePackageInterface;
 use Composer\Package\Package;
+use Symfony\Component\Process\Process;
 
-abstract class TestCase extends PolyfillTestCase
+abstract class TestCase extends \PHPUnit\Framework\TestCase
 {
     /**
      * @var ?VersionParser
@@ -42,16 +48,53 @@ abstract class TestCase extends PolyfillTestCase
      */
     private static $executableCache = array();
 
+    /**
+     * @var list<HttpDownloaderMock>
+     */
+    private $httpDownloaderMocks = [];
+    /**
+     * @var list<ProcessExecutorMock>
+     */
+    private $processExecutorMocks = [];
+    /**
+     * @var list<string>
+     */
+    private $tempComposerDirs = [];
+    /** @var string|null */
+    private $prevCwd = null;
+
+    protected function tearDown(): void
+    {
+        parent::tearDown();
+        foreach ($this->httpDownloaderMocks as $mock) {
+            $mock->assertComplete();
+        }
+        foreach ($this->processExecutorMocks as $mock) {
+            $mock->assertComplete();
+        }
+
+        if (null !== $this->prevCwd) {
+            chdir($this->prevCwd);
+            $this->prevCwd = null;
+            Platform::clearEnv('COMPOSER_HOME');
+            Platform::clearEnv('COMPOSER_DISABLE_XDEBUG_WARN');
+        }
+        $fs = new Filesystem();
+        foreach ($this->tempComposerDirs as $dir) {
+            $fs->removeDirectory($dir);
+        }
+    }
+
     /**
      * @return string
      */
-    public static function getUniqueTmpDirectory()
+    public static function getUniqueTmpDirectory(): string
     {
         $attempts = 5;
         $root = sys_get_temp_dir();
 
         do {
-            $unique = $root . DIRECTORY_SEPARATOR . uniqid('composer-test-' . rand(1000, 9000));
+            $unique = $root . DIRECTORY_SEPARATOR . uniqid('composer-test-' . random_int(1000, 9000));
 
             if (!file_exists($unique) && Silencer::call('mkdir', $unique, 0777)) {
                 return realpath($unique);
@@ -61,10 +104,46 @@ abstract class TestCase extends PolyfillTestCase
         throw new \RuntimeException('Failed to create a unique temporary directory.');
     }
 
+    /**
+     * Creates a composer.json / auth.json inside a temp dir and chdir() into it
+     *
+     * The directory will be cleaned up on tearDown automatically.
+     *
+     * @param mixed[] $composerJson
+     * @param mixed[] $authJson
+     * @return string the newly created temp dir
+     */
+    public function initTempComposer(array $composerJson = [], array $authJson = []): string
+    {
+        $dir = self::getUniqueTmpDirectory();
+
+        $this->tempComposerDirs[] = $dir;
+
+        $this->prevCwd = Platform::getCwd();
+
+        Platform::putEnv('COMPOSER_HOME', $dir.'/composer-home');
+        Platform::putEnv('COMPOSER_DISABLE_XDEBUG_WARN', '1');
+
+        chdir($dir);
+        file_put_contents($dir.'/composer.json', JsonFile::encode($composerJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_FORCE_OBJECT));
+        file_put_contents($dir.'/auth.json', JsonFile::encode($authJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_FORCE_OBJECT));
+
+        return $dir;
+    }
+
+    public function getApplicationTester(): ApplicationTester
+    {
+        $application = new Application();
+        $application->setAutoExit(false);
+        $application->setCatchExceptions(false);
+
+        return new ApplicationTester($application);
+    }
+
     /**
      * @return VersionParser
      */
-    protected static function getVersionParser()
+    protected static function getVersionParser(): VersionParser
     {
         if (!self::$parser) {
             self::$parser = new VersionParser();
@@ -78,7 +157,7 @@ abstract class TestCase extends PolyfillTestCase
      * @param string $version
      * @return Constraint
      */
-    protected function getVersionConstraint($operator, $version)
+    protected function getVersionConstraint($operator, string $version): Constraint
     {
         $constraint = new Constraint(
             $operator,
@@ -91,7 +170,7 @@ abstract class TestCase extends PolyfillTestCase
     }
 
     /**
-     * @template PackageClass of PackageInterface
+     * @template PackageClass of CompletePackage|CompleteAliasPackage
      *
      * @param  string $class  FQCN to be instantiated
      * @param  string $name
@@ -100,19 +179,27 @@ abstract class TestCase extends PolyfillTestCase
      * @return CompletePackage|CompleteAliasPackage|RootPackage|RootAliasPackage
      *
      * @phpstan-param class-string<PackageClass> $class
+     * @phpstan-return PackageClass
      */
-    protected function getPackage($name, $version, $class = 'Composer\Package\CompletePackage')
+    protected function getPackage(string $name = 'dummy/pkg', string $version = '1.0.0', string $class = 'Composer\Package\CompletePackage'): BasePackage
     {
         $normVersion = self::getVersionParser()->normalize($version);
 
         return new $class($name, $normVersion, $version);
     }
 
+    protected function getRootPackage(string $name = '__root__', string $version = '1.0.0'): RootPackage
+    {
+        $normVersion = self::getVersionParser()->normalize($version);
+
+        return new RootPackage($name, $normVersion, $version);
+    }
+
     /**
      * @param string $version
-     * @return AliasPackage|RootAliasPackage|CompleteAliasPackage
+     * @return ($package is RootPackage ? RootAliasPackage : ($package is CompletePackage ? CompleteAliasPackage : AliasPackage))
      */
-    protected function getAliasPackage(Package $package, $version)
+    protected function getAliasPackage(Package $package, string $version): AliasPackage
     {
         $normVersion = self::getVersionParser()->normalize($version);
 
@@ -130,7 +217,7 @@ abstract class TestCase extends PolyfillTestCase
      * @param array<string, array<string, string>> $config
      * @return void
      */
-    protected function configureLinks(PackageInterface $package, array $config)
+    protected function configureLinks(PackageInterface $package, array $config): void
     {
         $arrayLoader = new ArrayLoader();
 
@@ -149,11 +236,22 @@ abstract class TestCase extends PolyfillTestCase
         }
     }
 
+    /**
+     * @param array<mixed> $configOptions
+     */
+    protected function getConfig(array $configOptions = [], bool $useEnvironment = false): Config
+    {
+        $config = new Config($useEnvironment);
+        $config->merge(['config' => $configOptions], 'test');
+
+        return $config;
+    }
+
     /**
      * @param  string $directory
      * @return void
      */
-    protected static function ensureDirectoryExistsAndClear($directory)
+    protected static function ensureDirectoryExistsAndClear(string $directory): void
     {
         $fs = new Filesystem();
 
@@ -173,7 +271,7 @@ abstract class TestCase extends PolyfillTestCase
      *
      * @throws \PHPUnit\Framework\SkippedTestError
      */
-    protected function skipIfNotExecutable($executableName)
+    protected function skipIfNotExecutable(string $executableName): void
     {
         if (!isset(self::$executableCache[$executableName])) {
             $finder = new ExecutableFinder();
@@ -185,27 +283,6 @@ abstract class TestCase extends PolyfillTestCase
         }
     }
 
-    /**
-     * @param string      $exception
-     * @param string|null $message
-     * @param int|null    $code
-     * @return void
-     */
-    public function setExpectedException($exception, $message = null, $code = null)
-    {
-        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
-            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
-        }
-        if (method_exists($this, 'expectException')) {
-            $this->expectException($exception);
-            if (null !== $message) {
-                $this->expectExceptionMessage($message);
-            }
-        } else {
-            parent::setExpectedException($exception, $message, $code);
-        }
-    }
-
     /**
      * Transforms an escaped non-Windows command to match Windows escaping.
      *
@@ -213,7 +290,7 @@ abstract class TestCase extends PolyfillTestCase
      *
      * @return string The transformed command
      */
-    protected function getCmd($cmd)
+    protected function getCmd(string $cmd): string
     {
         if (Platform::isWindows()) {
             $cmd = Preg::replaceCallback("/('[^']*')/", function ($m) {
@@ -226,4 +303,29 @@ abstract class TestCase extends PolyfillTestCase
 
         return $cmd;
     }
+
+    protected function getHttpDownloaderMock(IOInterface $io = null, Config $config = null): HttpDownloaderMock
+    {
+        $this->httpDownloaderMocks[] = $mock = new HttpDownloaderMock($io, $config);
+
+        return $mock;
+    }
+
+    protected function getProcessExecutorMock(): ProcessExecutorMock
+    {
+        $this->processExecutorMocks[] = $mock = new ProcessExecutorMock($this->getMockBuilder(Process::class));
+
+        return $mock;
+    }
+
+    protected function createTempFile(?string $dir = null): string
+    {
+        $dir = $dir ?? sys_get_temp_dir();
+        $name = tempnam($dir, 'c');
+        if ($name === false) {
+            throw new \UnexpectedValueException('tempnam failed to create a temporary file in '.$dir);
+        }
+
+        return $name;
+    }
 }
