@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -26,7 +26,7 @@ class IniHelperTest extends TestCase
      */
     public static $envOriginal;
 
-    public function testWithNoIni()
+    public function testWithNoIni(): void
     {
         $paths = array(
             '',
@@ -37,7 +37,7 @@ class IniHelperTest extends TestCase
         $this->assertEquals($paths, IniHelper::getAll());
     }
 
-    public function testWithLoadedIniOnly()
+    public function testWithLoadedIniOnly(): void
     {
         $paths = array(
             'loaded.ini',
@@ -47,7 +47,7 @@ class IniHelperTest extends TestCase
         $this->assertStringContainsString('loaded.ini', IniHelper::getMessage());
     }
 
-    public function testWithLoadedIniAndAdditional()
+    public function testWithLoadedIniAndAdditional(): void
     {
         $paths = array(
             'loaded.ini',
@@ -60,7 +60,7 @@ class IniHelperTest extends TestCase
         $this->assertEquals($paths, IniHelper::getAll());
     }
 
-    public function testWithoutLoadedIniAndAdditional()
+    public function testWithoutLoadedIniAndAdditional(): void
     {
         $paths = array(
             '',
@@ -73,7 +73,7 @@ class IniHelperTest extends TestCase
         $this->assertEquals($paths, IniHelper::getAll());
     }
 
-    public static function setUpBeforeClass()
+    public static function setUpBeforeClass(): void
     {
         // Register our name with XdebugHandler
         $xdebug = new XdebugHandler('composer');
@@ -81,7 +81,7 @@ class IniHelperTest extends TestCase
         self::$envOriginal = getenv('COMPOSER_ORIGINAL_INIS');
     }
 
-    public static function tearDownAfterClass()
+    public static function tearDownAfterClass(): void
     {
         // Restore original state
         if (false !== self::$envOriginal) {
@@ -96,7 +96,7 @@ class IniHelperTest extends TestCase
      *
      * @return void
      */
-    protected function setEnv(array $paths)
+    protected function setEnv(array $paths): void
     {
         putenv('COMPOSER_ORIGINAL_INIS='.implode(PATH_SEPARATOR, $paths));
     }
